==> merengue-0.8.0-b2.tar.gz: merengue-0.8.0-b2/plugins/event/admin.py <==
# Copyright (c) 2010 by Yaco Sistemas
#
# This file is part of Merengue.
#
# Merengue is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Merengue is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Merengue.  If not, see <http://www.gnu.org/licenses/>.

from django.conf import settings

from transmeta import get_fallback_fieldname

from merengue.base.admin import BaseContentAdmin, BaseCategoryAdmin
from merengue.section.admin import SectionContentAdmin
from plugins.event.forms import EventAdminForm


class EventCategoryAdmin(BaseCategoryAdmin):
    ordering = (get_fallback_fieldname('name'), )
    search_fields = (get_fallback_fieldname('name'), )


class EventAdmin(BaseContentAdmin):
    ordering = (get_fallback_fieldname('name'), )
    exclude = ('expire_date', )
    list_display = ('name', 'start', 'end', 'status', 'user_modification_date',
                    'last_editor')
    form = EventAdminForm
    if settings.USE_GIS:
        list_display = list_display + ('google_minimap', )
    list_filter = ('categories', 'status', 'user_modification_date', )


class EventSectionAdmin(SectionContentAdmin, EventAdmin):
    manage_contents = True

==> merengue-0.8.2.tar.gz: merengue-0.8.2/plugins/event/admin.py <==
# Copyright (c) 2010 by Yaco Sistemas
#
# This file is part of Merengue.
#
# Merengue is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Merengue is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Merengue.  If not, see <http://www.gnu.org/licenses/>.

from django.conf import settings

from transmeta import get_fallback_fieldname

from merengue.base.admin import BaseContentAdmin, BaseCategoryAdmin
from merengue.section.admin import SectionContentAdmin
from plugins.event.forms import EventAdminForm


class EventCategoryAdmin(BaseCategoryAdmin):
    ordering = (get_fallback_fieldname('name'), )
    search_fields = (get_fallback_fieldname('name'), )


class EventAdmin(BaseContentAdmin):
    ordering = (get_fallback_fieldname('name'), )
    exclude = ('expire_date', )
    list_display = ('name', 'start', 'end', 'workflow_status', 'user_modification_date',
                    'last_editor')
    form = EventAdminForm
    if settings.USE_GIS:
        list_display = list_display + ('google_minimap', )
    list_filter = ('categories', 'workflow_status', 'user_modification_date', )


class EventSectionAdmin(SectionContentAdmin, EventAdmin):
    manage_contents = True
